@@ -52,7 +52,7 @@ MyApp::MyApp() : Gnome::App("MyApp","MyApp")
         UI::RadioTree(radioitems2)
       };
 
-    UI::Info menus[]=
+    UI::SubTree menus[]=
        { 
          UI::Menu("Items",radio_menu)
        };
